plot_kpoints — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# plot_kpoints

ElectronicBandStructure.plot_kpoints(reduced=False, show_brillouin_zone=True, color='r', point_size=4.0, render_points_as_spheres=True, transformation_matrix=None)

  This needs to be moved to core.KPath and updated new implementation of pyvista PolyData

  This method will plot the K points in pyvista

  Parameters:

    - reduced (bool, optional) – Determines wether to plot the kpoints in the reduced or cartesian basis, defaults to False

    - show_brillouin_zone (bool, optional) – Boolean to show the Brillouin zone, defaults to True

    - color (str, optional) – Color of the points, defaults to “r”

    - point_size (float, optional) – Size of points, defaults to 4.0

    - render_points_as_spheres (bool, optional) – Boolean for how points are rendered, defaults to True

    - transformation_matrix (np.ndarray, optional, optional) – Reciprocal Lattice Matrix, defaults to None

  Returns:

    None – None